#!/usr/bin/env python
#
# Simple script to import a file into the datastore.
# 
# Authors:
#
#    Reinier Heeres <reinier@heeres.eu>
#    Phil Bordelon <phil@thenexusproject.org>
#    Michael Vorburger <mike@vorburger.ch> (MIME type handling)
#
# Released under the MIT license, shown below.
#
#####
#
# Copyright (c) 2007, 2008 Reinier Heeres and Phil Bordelon
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
#####

import sys
import os
import optparse
import mimetypes

from sugar.datastore import datastore

def build_option_parser():

    usage = "Usage: %prog <file> [-m MIMETYPE] [-t TITLE] [-d DESC] [-T tag1 [-T tag2 ...]]"
    parser = optparse.OptionParser(usage=usage)

    parser.add_option("-t", "--title", action="store", dest="title",
     help="Set the title of the journal entry to TITLE", metavar="TITLE",
     default=None)
    parser.add_option("-d", "--description", action="store",
     dest="description", metavar="DESC",
     help="Set the description of the journal entry to DESC",
     default=None)
    parser.add_option("-m", "--mimetype", action="store",
     dest="mimetype", metavar="MIMETYPE",
     help="Force the file's MIME-type to MIMETYPE (optional; normally automatically detected)",
     default=None)
    parser.add_option("-T", "--tag", action="append", dest="tag_list",
     help="Add tag TAG to the journal entry's tags; this option can be repeated",
     metavar="TAG")
    return parser

if __name__ == "__main__":

    parser = build_option_parser()
    options, args = parser.parse_args()
    if len(args) < 1:
        parser.print_help()
        exit(0)
    
    fname = args[0]
    absname = os.path.abspath(fname)
    if not os.path.exists(absname):
        print 'Error: File does not exist.'
        parser.print_help()
        exit(0)

    if options.mimetype:
        # If MIME type is set in options, that's the one we'll use
        mimetype = options.mimetype
    else:
        # Otherwise we'll try to determine it automatically
        mimetype = mimetypes.guess_type(absname)[0]
        
    if mimetype == None:
        print 'Error: MIME type could not be guessed (file has wrong or missing extension?) and needs to be given.'
        parser.print_help()
        exit(0)
    
    try:
        entry = datastore.create()
        entry.set_file_path(absname)

        # Set the mimetype to the provided one.
        entry.metadata['mime_type'] = mimetype

        # If no title is given, use the filename.
        if options.title:
            entry.metadata['title'] = options.title
        else:
            entry.metadata['title'] = fname

        # Use the description given, otherwise leave it blank.
        if options.description:
            entry.metadata['description'] = options.description

        # Lastly, if any tags are given, combine them into a single string
        # and save them.
        if options.tag_list:
            tag_string = " ".join(options.tag_list)
            entry.metadata['tags'] = tag_string

        datastore.write(entry)
        print 'Created as %s' % (entry.object_id)
    
    except Exception, e:
        print 'Error: %s' % (e)

    finally:
        entry.destroy()
